@@ -109,8 +109,8 @@ orderMCMCbasemax<-function(n,nsmall,startorder,iterations,stepsave,moveprobs,par
   result$orderscores<-L3
   result$orders<-L4
   result$maxscore<-maxscore
-  result$maxdag<-maxdag
-
+  result$maxdag<-Matrix(maxdag,sparse=TRUE)
+  
   return(result)
 }
 
